@@ -148,8 +148,14 @@ def main():
         sim.main(sim_job)
         common.exit()
     if cli_args.command == 'regr':
-        cache.check_ip_str(cli_args.ip.lower())
-        regr.main(cli_args.ip.lower(), cli_args.regr.lower(), cli_args.app, cli_args.dry)
+        cli_ip_name = cli_args.ip.lower()
+        cli_target_name = "default"
+        if "#" in cli_ip_name:
+            cli_ip_name, cli_target_name = cli_ip_name.split("#")
+            cli_ip_name     = cli_ip_name    .replace("#", "")
+            cli_target_name = cli_target_name.replace("#", "")
+        cache.check_ip_str(cli_ip_name)
+        regr.main(cli_ip_name, cli_target_name, cli_args.regr.lower(), cli_args.app, cli_args.dry)
         common.exit()
     
     common.fatal("No command specified")
@@ -239,7 +245,17 @@ def build_parser():
 
 
 def create_sim_job(cli_args):
-    sim_job = sim.SimulationJob(cli_args.ip.lower())
+    cli_ip_name = cli_args.ip.lower()
+    cli_target_name = ""
+    if "#" in cli_ip_name:
+        cli_ip_name, cli_target_name = cli_ip_name.split("#")
+        cli_ip_name     = cli_ip_name    .replace("#", "")
+        cli_target_name = cli_target_name.replace("#", "")
+    
+    sim_job = sim.SimulationJob(cli_ip_name)
+    if cli_target_name != "":
+        sim_job.target_name = cli_target_name
+    
     sim_job.is_regression = False
     
     if cli_args.app != None:
