@@ -302,7 +302,7 @@ def publish_ip(ip_str, username="", password="", org=""):
         token = user.login()
     else:
         token = user.login(username, password, True)
-    dox.gen_doxygen(target_name, inc_dep_src=True, inc_tags=False)
+    dox.gen_doxygen(target_name, inc_deps=True, inc_tags=False)
     do_publish_ip(ip, token, org)
 
 
